@@ -53,7 +53,7 @@ def intersected_dirf_model(mdcg: MDCGraph, starter_vertex: OccOrCT,
     # ------------------------------------------------------------------------ #
     # Constants
     # ------------------------------------------------------------------------ #
-    big_m = mdcg.multiplied_card()
+    big_m = mdcg.multiplied_card() // 2
 
     # ------------------------------------------------------------------------ #
     # Problem
