@@ -1,6 +1,6 @@
 # -*- coding=utf-8 -*-
 
-"""Nested inverted fragments PuLP ILP."""
+"""Heaviest presence score path PuLP ILP."""
 
 from typing import Optional
 
@@ -36,7 +36,7 @@ def best_presscore_model(mdcg: MDCGraph, starter_vertex: OccOrCT,
         Multiplied doubled contig graph
     starter_vertex : OccOrCT
         Starter vertex
-    result : ScaffoldingResult, optional
+    fix_result : ScaffoldingResult, optional
         Previous scaffolding result, by default `None`
 
     Returns
@@ -49,7 +49,7 @@ def best_presscore_model(mdcg: MDCGraph, starter_vertex: OccOrCT,
     # ------------------------------------------------------------------------ #
     # Constants
     # ------------------------------------------------------------------------ #
-    big_m = mdcg.multiplied_card()
+    big_m = mdcg.multiplied_card() // 2
 
     # ------------------------------------------------------------------------ #
     # Problem
