@@ -3,18 +3,12 @@
 """PuLP path model."""
 
 
-from typing import Union
-
 from pulp import LpAffineExpression, LpProblem, lpSum
 from revsymg.index_lib import FORWARD_INT, REVERSE_INT
 
 from khloraascaf.ilp.dirf_sets import dirf_other
 from khloraascaf.ilp.invf_sets import invf_other
-from khloraascaf.ilp.pulp_var_db import (
-    PuLPVarDirFModel,
-    PuLPVarInvFModel,
-    PuLPVarPath,
-)
+from khloraascaf.ilp.pulp_var_db import PuLPVarPath, PuLPVarRepFModelT
 from khloraascaf.multiplied_doubled_contig_graph import (
     MULT_ATTR,
     MDCGraph,
@@ -27,7 +21,7 @@ from khloraascaf.result import ScaffoldingResult
 #                                  OBJECTIVES                                  #
 # ============================================================================ #
 def longuest_contiguous_repeat(prob: LpProblem,
-                               var: Union[PuLPVarInvFModel, PuLPVarDirFModel],
+                               var: PuLPVarRepFModelT,
                                mdcg: MDCGraph):
     """Pair of the longuest contigous repeats model objective function.
 
@@ -53,7 +47,7 @@ def longuest_contiguous_repeat(prob: LpProblem,
 #                      Repeats Are Sub-paths In The Graph                      #
 # ---------------------------------------------------------------------------- #
 def pairs_in_path(prob: LpProblem,
-                  var: Union[PuLPVarInvFModel, PuLPVarDirFModel],
+                  var: PuLPVarRepFModelT,
                   mdcg: MDCGraph):
     """Constraint defining the link between m and i variables.
 
@@ -91,7 +85,7 @@ def pairs_in_path(prob: LpProblem,
 #   in the path and are candidate of repeats
 #
 def alpha_definition(prob: LpProblem,
-                     var: Union[PuLPVarInvFModel, PuLPVarDirFModel],
+                     var: PuLPVarRepFModelT,
                      mdcg: MDCGraph, big_m: int):
     r"""Constraint defining alpha variables.
 
@@ -134,7 +128,7 @@ def alpha_definition(prob: LpProblem,
 # Forbidden relative positioning of the pairs of repeated fragments
 #
 def forbidden_pairing_definition(prob: LpProblem,
-                                 var: Union[PuLPVarInvFModel, PuLPVarDirFModel],
+                                 var: PuLPVarRepFModelT,
                                  mdcg: MDCGraph):
     """Constraint defining the forbidden pairing cases.
 
@@ -180,7 +174,7 @@ def forbidden_pairing_definition(prob: LpProblem,
 #                               Repeat Contiguity                              #
 # ---------------------------------------------------------------------------- #
 def adjacent_fragments(prob: LpProblem,
-                       var: Union[PuLPVarInvFModel, PuLPVarDirFModel],
+                       var: PuLPVarRepFModelT,
                        mdcg: MDCGraph):
     """Constraint defining the adjacency of repeated fragments.
 
@@ -223,7 +217,7 @@ def adjacent_fragments(prob: LpProblem,
 #                              Speed-up The Model                              #
 # ---------------------------------------------------------------------------- #
 def occurences_priority(prob: LpProblem,
-                        var: Union[PuLPVarInvFModel, PuLPVarDirFModel],
+                        var: PuLPVarRepFModelT,
                         mdcg: MDCGraph):
     """Constraint for occurences priority.
 
@@ -337,7 +331,7 @@ def fix_repeats_subpaths(prob: LpProblem, var: PuLPVarPath,
 # ============================================================================ #
 #                                   FUNCTIONS                                  #
 # ============================================================================ #
-def pos(var: Union[PuLPVarInvFModel, PuLPVarDirFModel], mdcg: MDCGraph,
+def pos(var: PuLPVarRepFModelT, mdcg: MDCGraph,
         vertex: OccOrCT) -> LpAffineExpression:
     """Give the position of vertex in the path.
 
