@@ -283,7 +283,8 @@ class PuLPVarPresScoreModel(PuLPVarPath):
         PuLPVarPath.__init__(self, mdcg, starter_vertex, big_m)
 
 
-PuLPVarModelT = Union[PuLPVarInvFModel, PuLPVarDirFModel, PuLPVarPresScoreModel]
+PuLPVarRepFModelT = Union[PuLPVarInvFModel, PuLPVarDirFModel]
+PuLPVarModelT = Union[PuLPVarRepFModelT, PuLPVarPresScoreModel]
 
 
 # ============================================================================ #
