@@ -20,7 +20,7 @@ from khloraascaf.ilp.pulp_var_db import (
     PuLPVarInvFModel,
     PuLPVarModelT,
 )
-from khloraascaf.lib import DR_CODE, IR_CODE, UN_CODE, RegionCodeT
+from khloraascaf.lib import DR_CODE, IR_CODE, SC_CODE, RegionCodeT
 from khloraascaf.multiplied_doubled_contig_graph import (
     COCC_IND,
     COR_IND,
@@ -58,7 +58,7 @@ class ScaffoldingResult():
     Warning
     -------
     You must not call the constructor, you must only deal with the objects
-    that have been already instancied.
+    that have been already instanced.
     You can use the class name to type your variables.
     """
 
@@ -70,7 +70,7 @@ class ScaffoldingResult():
                  status: int, opt_value: float,
                  region_map: OrRegMapT,
                  regions_occorc: tuple[RegOccOrCT, ...],
-                 unique_regions: tuple[IndexT, ...],
+                 sc_regions: tuple[IndexT, ...],
                  ir_regions: tuple[IndexT, ...],
                  dr_regions: tuple[IndexT, ...]):
         """The Initializer."""
@@ -88,14 +88,14 @@ class ScaffoldingResult():
         #
         self.__region_map: OrRegMapT = region_map
         self.__regions_occorc: tuple[RegOccOrCT, ...] = regions_occorc
-        self.__unique_regions: tuple[IndexT, ...] = unique_regions
+        self.__sc_regions: tuple[IndexT, ...] = sc_regions
         self.__ir_regions: tuple[IndexT, ...] = ir_regions
         self.__dr_regions: tuple[IndexT, ...] = dr_regions
 
     # ~*~ Getter ~*~
 
     def last_ilp(self) -> RegionCodeT:
-        """Returns last ILP code.
+        """Return last ILP code.
 
         Returns
         -------
@@ -147,7 +147,7 @@ class ScaffoldingResult():
         yield from self.__region_map
 
     def region_occorc(self, region_index: IndexT) -> Iterator[OccOrCT]:
-        """Iterate over the multiplied oriented contig of the region.
+        """Iterate over the multiplied oriented contigs of the region.
 
         Parameters
         ----------
@@ -171,18 +171,18 @@ class ScaffoldingResult():
         """
         return len(self.__regions_occorc)
 
-    def unique_regions(self) -> Iterator[IndexT]:
-        """Iterate over unique regions index.
+    def sc_regions(self) -> Iterator[IndexT]:
+        """Iterate over the single copy indices.
 
         Yields
         ------
         IndexT
-            Unique region index
+            Single copy region index
         """
-        yield from self.__unique_regions
+        yield from self.__sc_regions
 
     def ir_regions(self) -> Iterator[IndexT]:
-        """Iterate over inverted repeats index.
+        """Iterate over inverted repeat indices.
 
         Yields
         ------
@@ -192,7 +192,7 @@ class ScaffoldingResult():
         yield from self.__ir_regions
 
     def dr_regions(self) -> Iterator[IndexT]:
-        """Iterate over direct repeats index.
+        """Iterate over direct repeat indices.
 
         Yields
         ------
@@ -232,14 +232,14 @@ class _ScaffoldingResultBuilder():
         #
         self.__region_map: _OrRegMapT = []
         self.__regions_occorc: list[_RegOccOrCT] = []
-        self.__unique_regions: list[IndexT] = []
+        self.__sc_regions: list[IndexT] = []
         self.__ir_regions: list[IndexT] = []
         self.__dr_regions: list[IndexT] = []
 
     # ~*~ Setter ~*~
 
-    def add_unique_region(self) -> IndexT:
-        """Add an unique region.
+    def add_sc_region(self) -> IndexT:
+        """Add an single copy region.
 
         Returns
         -------
@@ -249,7 +249,7 @@ class _ScaffoldingResultBuilder():
         region_index = len(self.__regions_occorc)
         self.__regions_occorc.append([])
         self.__region_map.append((region_index, FORWARD_INT))
-        self.__unique_regions.append(region_index)
+        self.__sc_regions.append(region_index)
         return region_index
 
     def add_ir_region(self,
@@ -352,7 +352,7 @@ class _ScaffoldingResultBuilder():
             self.__fix_opt_value(prob),
             tuple(self.__region_map),
             tuple(tuple(regoccorc) for regoccorc in self.__regions_occorc),
-            tuple(self.__unique_regions),
+            tuple(self.__sc_regions),
             tuple(self.__ir_regions),
             tuple(self.__dr_regions),
         )
@@ -403,8 +403,8 @@ def path_to_regions(mdcg: MDCGraph, starter_vertex: OccOrCT,
     # Init regions
     # ------------------------------------------------------------------------ #
     result_builder = _ScaffoldingResultBuilder()
-    reg_code = UN_CODE
-    region_index = result_builder.add_unique_region()
+    reg_code = SC_CODE
+    region_index = result_builder.add_sc_region()
 
     initial_vertex = __find_initial(
         mdcg, starter_vertex, var, set_invf_paired, set_dirf_paired)
@@ -438,7 +438,7 @@ def path_to_regions(mdcg: MDCGraph, starter_vertex: OccOrCT,
             #
             # Previous UNIQ region
             #
-            if new_reg_code == UN_CODE:  # pylint: disable=compare-to-zero
+            if new_reg_code == SC_CODE:  # pylint: disable=compare-to-zero
                 result_builder.add_occorc_to_region(v, region_index)
             #
             # Previous or new IR region
@@ -463,8 +463,8 @@ def path_to_regions(mdcg: MDCGraph, starter_vertex: OccOrCT,
             #
             # New UNIQ region
             #
-            if new_reg_code == UN_CODE:  # pylint: disable=compare-to-zero
-                region_index = result_builder.add_unique_region()
+            if new_reg_code == SC_CODE:  # pylint: disable=compare-to-zero
+                region_index = result_builder.add_sc_region()
                 result_builder.add_occorc_to_region(v, region_index)
             #
             # New or already existing IR region
@@ -772,7 +772,7 @@ def __find_initial(mdcg: MDCGraph, starter_vertex: OccOrCT,
                    set_dirf_paired: set[OccOrCT]) -> OccOrCT:
     """The first vertex of the starter's region.
 
-    In case of circular unique region, it returns starter_vertex.
+    In case of circular single copy region, it returns starter_vertex.
 
     Parameters
     ----------
@@ -825,14 +825,14 @@ def __get_region_code(v: OccOrCT, set_invf_paired: set[OccOrCT],
     Returns
     -------
     RegionCodeT
-        Code of the region (0: UN; 1: IR; 2: DR)
+        Code of the region (0: SC; 1: IR; 2: DR)
     """
     if dirf_canonical(v) in set_dirf_paired:
         return DR_CODE
     if ((v[COCC_IND] - v[COR_IND]) % 2 == 0  # pylint: disable=compare-to-zero
             and invf_canonical(v) in set_invf_paired):
         return IR_CODE
-    return UN_CODE
+    return SC_CODE
 
 
 def __is_repeat_contiguous(u: OccOrCT, v: OccOrCT, var: PuLPVarModelT,
