@@ -13,10 +13,10 @@ from khloraascaf.exceptions import (
     CombineScaffoldingError,
     RepeatScaffoldingError,
     ScaffoldingError,
+    SingleCopyScaffoldingError,
     UnfeasibleDR,
     UnfeasibleIR,
-    UnfeasibleUN,
-    UniqueScaffoldingError,
+    UnfeasibleSC,
     WrongRegionCode,
 )
 from khloraascaf.ilp.pulp_max_dirf import intersected_dirf_model
@@ -46,7 +46,7 @@ from khloraascaf.lib import (
     DR_CODE,
     IR_CODE,
     REGION_CODE_TO_ID,
-    UN_CODE,
+    SC_CODE,
     RegionCodeT,
 )
 from khloraascaf.multiplied_doubled_contig_graph import (
@@ -264,14 +264,14 @@ def combine_scaffolding_problems(mdcg: MDCGraph, starter_vertex: OccOrCT,
         height += 1
 
     # ------------------------------------------------------------------------ #
-    # Unique regions scaffolding
+    # Single copy regions scaffolding
     # ------------------------------------------------------------------------ #
     try:
-        opti_results = combine_with_unique_scaffolding(
+        opti_results = combine_singlecopy_scaffolding(
             opti_results, mdcg, starter_vertex,
             solver, outdir, instance_name, debug,
         )
-    except UniqueScaffoldingError as exc:
+    except SingleCopyScaffoldingError as exc:
         # TODO logging exception here
         raise CombineScaffoldingError() from exc
 
@@ -343,12 +343,12 @@ def combine_repeat_scaffolding(opti_results: tuple[ScaffoldingResult, ...],
     return tuple(new_results) if new_results else opti_results
 
 
-def combine_with_unique_scaffolding(opti_results: tuple[ScaffoldingResult, ...],
-                                    mdcg: MDCGraph, starter_vertex: OccOrCT,
-                                    solver: str, outdir: Path,
-                                    instance_name: str, debug: bool) -> (
-                                        tuple[ScaffoldingResult, ...]):
-    """Combine best previous results with unique scaffolding.
+def combine_singlecopy_scaffolding(opti_results: tuple[ScaffoldingResult, ...],
+                                   mdcg: MDCGraph, starter_vertex: OccOrCT,
+                                   solver: str, outdir: Path,
+                                   instance_name: str, debug: bool) -> (
+        tuple[ScaffoldingResult, ...]):
+    """Combine best previous results with single copy scaffolding.
 
     Parameters
     ----------
@@ -374,22 +374,22 @@ def combine_with_unique_scaffolding(opti_results: tuple[ScaffoldingResult, ...],
 
     Raises
     ------
-    UniqueScaffoldingError
-        One of the unique region scaffolding has failed
+    SingleCopyScaffoldingError
+        One of the single copy region scaffolding has failed
     """
     best_opt_value = 0.0
     new_results = []
     for opti_result in (opti_results if opti_results else (None,)):
         try:
             result = scaffolding_region(
-                UN_CODE, mdcg, starter_vertex,
+                SC_CODE, mdcg, starter_vertex,
                 solver, outdir, instance_name,
                 fix_result=opti_result,
                 debug=debug,
             )
-        except UnfeasibleUN as exc:
+        except UnfeasibleSC as exc:
             # TODO logging here print(exc, file=sys.stderr)
-            raise UniqueScaffoldingError() from exc
+            raise SingleCopyScaffoldingError() from exc
 
         if result.opt_value() > best_opt_value:
             best_opt_value = result.opt_value()
@@ -442,7 +442,7 @@ def scaffolding_region(region_code: RegionCodeT,
         The combinatorial problem is unfeasible
     UnfeasibleDR
         The combinatorial problem is unfeasible
-    UnfeasibleUN
+    UnfeasibleSC
         The combinatorial problem is unfeasible
 
     Warnings
@@ -468,9 +468,9 @@ def scaffolding_region(region_code: RegionCodeT,
     elif region_code == DR_CODE:
         model_fn = intersected_dirf_model
         unfeasible_exc = UnfeasibleDR
-    elif region_code == UN_CODE:
+    elif region_code == SC_CODE:
         model_fn = best_presscore_model
-        unfeasible_exc = UnfeasibleUN
+        unfeasible_exc = UnfeasibleSC
     else:
         raise WrongRegionCode(region_code)
 
