@@ -10,7 +10,7 @@ import subprocess
 from pathlib import Path
 
 from khloraascaf.inputs import INSTANCE_NAME_DEF, SOLVER_CBC
-from khloraascaf.lib import DR_REGION_ID, IR_REGION_ID, UN_REGION_ID
+from khloraascaf.lib import DR_REGION_ID, IR_REGION_ID, SC_REGION_ID
 from khloraascaf.outputs import (
     fmt_contigs_of_regions_filename,
     fmt_map_of_regions_filename,
@@ -27,86 +27,86 @@ TEST_DIR: Path = Path(__file__).parent.absolute()
 _TOY_DATADIR = TEST_DIR / 'data'
 
 # ---------------------------------------------------------------------------- #
-#                                    IR - UN                                   #
+#                                    IR - SC                                   #
 # ---------------------------------------------------------------------------- #
-_IR_UN_DIR = _TOY_DATADIR / 'ir_un'
-_IR_UN_CONTIG_ATTRS = _IR_UN_DIR / 'contig_attrs.tsv'
-_IR_UN_CONTIG_LINKS = _IR_UN_DIR / 'contig_links.tsv'
-_IR_UN_CONTIG_STARTER = 'C0'
-_IR_UN_SOL_REGMAP = _IR_UN_DIR / 'map_of_regions_sol.tsv'
-_IR_UN_SOL_REGCTG_F = _IR_UN_DIR / 'contigs_of_regions_sol_0.tsv'
-_IR_UN_SOL_REGCTG_R = _IR_UN_DIR / 'contigs_of_regions_sol_1.tsv'
+_IR_SC_DIR = _TOY_DATADIR / 'ir_sc'
+_IR_SC_CONTIG_ATTRS = _IR_SC_DIR / 'contig_attrs.tsv'
+_IR_SC_CONTIG_LINKS = _IR_SC_DIR / 'contig_links.tsv'
+_IR_SC_CONTIG_STARTER = 'C0'
+_IR_SC_SOL_REGMAP = _IR_SC_DIR / 'map_of_regions_sol.tsv'
+_IR_SC_SOL_REGCTG_F = _IR_SC_DIR / 'contigs_of_regions_sol_0.tsv'
+_IR_SC_SOL_REGCTG_R = _IR_SC_DIR / 'contigs_of_regions_sol_1.tsv'
 
 # ---------------------------------------------------------------------------- #
-#                                    DR - UN                                   #
+#                                    DR - SC                                   #
 # ---------------------------------------------------------------------------- #
-_DR_UN_DIR = _TOY_DATADIR / 'dr_un'
-_DR_UN_CONTIG_ATTRS = _DR_UN_DIR / 'contig_attrs.tsv'
-_DR_UN_CONTIG_LINKS = _DR_UN_DIR / 'contig_links.tsv'
-_DR_UN_CONTIG_STARTER = 'C0'
-_DR_UN_SOL_REGMAP = _DR_UN_DIR / 'map_of_regions_sol.tsv'
-_DR_UN_SOL_REGCTG = _DR_UN_DIR / 'contigs_of_regions_sol.tsv'
+_DR_SC_DIR = _TOY_DATADIR / 'dr_sc'
+_DR_SC_CONTIG_ATTRS = _DR_SC_DIR / 'contig_attrs.tsv'
+_DR_SC_CONTIG_LINKS = _DR_SC_DIR / 'contig_links.tsv'
+_DR_SC_CONTIG_STARTER = 'C0'
+_DR_SC_SOL_REGMAP = _DR_SC_DIR / 'map_of_regions_sol.tsv'
+_DR_SC_SOL_REGCTG = _DR_SC_DIR / 'contigs_of_regions_sol.tsv'
 
 # ---------------------------------------------------------------------------- #
-#                                      UN                                      #
+#                                      SC                                      #
 # ---------------------------------------------------------------------------- #
-_UN_DIR = _TOY_DATADIR / 'un'
-_UN_CONTIG_ATTRS = _UN_DIR / 'contig_attrs.tsv'
-_UN_CONTIG_LINKS = _UN_DIR / 'contig_links.tsv'
-_UN_CONTIG_STARTER = 'C0'
-_UN_SOL_REGMAP = _UN_DIR / 'map_of_regions_sol.tsv'
-_UN_SOL_REGCTG = _UN_DIR / 'contigs_of_regions_sol.tsv'
+_SC_DIR = _TOY_DATADIR / 'sc'
+_SC_CONTIG_ATTRS = _SC_DIR / 'contig_attrs.tsv'
+_SC_CONTIG_LINKS = _SC_DIR / 'contig_links.tsv'
+_SC_CONTIG_STARTER = 'C0'
+_SC_SOL_REGMAP = _SC_DIR / 'map_of_regions_sol.tsv'
+_SC_SOL_REGCTG = _SC_DIR / 'contigs_of_regions_sol.tsv'
 
 # ---------------------------------------------------------------------------- #
-#                                 IR - DR - UN                                 #
+#                                 IR - DR - SC                                 #
 # ---------------------------------------------------------------------------- #
-_IR_DR_UN_DIR = _TOY_DATADIR / 'ir_dr_un'
-_IR_DR_UN_CONTIG_ATTRS = _IR_DR_UN_DIR / 'contig_attrs.tsv'
-_IR_DR_UN_CONTIG_LINKS = _IR_DR_UN_DIR / 'contig_links.tsv'
-_IR_DR_UN_CONTIG_STARTER = 'C0'
-_IR_DR_UN_SOL_REGMAP = _IR_DR_UN_DIR / 'map_of_regions_sol.tsv'
-_IR_DR_UN_SOL_REGCTG_F = _IR_DR_UN_DIR / 'contigs_of_regions_sol_0.tsv'
-_IR_DR_UN_SOL_REGCTG_R = _IR_DR_UN_DIR / 'contigs_of_regions_sol_1.tsv'
+_IR_DR_SC_DIR = _TOY_DATADIR / 'ir_dr_sc'
+_IR_DR_SC_CONTIG_ATTRS = _IR_DR_SC_DIR / 'contig_attrs.tsv'
+_IR_DR_SC_CONTIG_LINKS = _IR_DR_SC_DIR / 'contig_links.tsv'
+_IR_DR_SC_CONTIG_STARTER = 'C0'
+_IR_DR_SC_SOL_REGMAP = _IR_DR_SC_DIR / 'map_of_regions_sol.tsv'
+_IR_DR_SC_SOL_REGCTG_F = _IR_DR_SC_DIR / 'contigs_of_regions_sol_0.tsv'
+_IR_DR_SC_SOL_REGCTG_R = _IR_DR_SC_DIR / 'contigs_of_regions_sol_1.tsv'
 
 # ---------------------------------------------------------------------------- #
-#                                 DR - IR - UN                                 #
+#                                 DR - IR - SC                                 #
 # ---------------------------------------------------------------------------- #
-_DR_IR_UN_DIR = _TOY_DATADIR / 'dr_ir_un'
-_DR_IR_UN_CONTIG_ATTRS = _DR_IR_UN_DIR / 'contig_attrs.tsv'
-_DR_IR_UN_CONTIG_LINKS = _DR_IR_UN_DIR / 'contig_links.tsv'
-_DR_IR_UN_CONTIG_STARTER = 'C0'
-_DR_IR_UN_SOL_REGMAP = _DR_IR_UN_DIR / 'map_of_regions_sol.tsv'
-_DR_IR_UN_SOL_REGCTG_F = _DR_IR_UN_DIR / 'contigs_of_regions_sol_0.tsv'
-_DR_IR_UN_SOL_REGCTG_R = _DR_IR_UN_DIR / 'contigs_of_regions_sol_1.tsv'
+_DR_IR_SC_DIR = _TOY_DATADIR / 'dr_ir_sc'
+_DR_IR_SC_CONTIG_ATTRS = _DR_IR_SC_DIR / 'contig_attrs.tsv'
+_DR_IR_SC_CONTIG_LINKS = _DR_IR_SC_DIR / 'contig_links.tsv'
+_DR_IR_SC_CONTIG_STARTER = 'C0'
+_DR_IR_SC_SOL_REGMAP = _DR_IR_SC_DIR / 'map_of_regions_sol.tsv'
+_DR_IR_SC_SOL_REGCTG_F = _DR_IR_SC_DIR / 'contigs_of_regions_sol_0.tsv'
+_DR_IR_SC_SOL_REGCTG_R = _DR_IR_SC_DIR / 'contigs_of_regions_sol_1.tsv'
 
 
 # ============================================================================ #
 #                                TEST FUNCTIONS                                #
 # ============================================================================ #
 # ---------------------------------------------------------------------------- #
-#                                    IR - UN                                   #
+#                                    IR - SC                                   #
 # ---------------------------------------------------------------------------- #
-def test_ir_un_func():
-    """Test IR-UN toy example."""
-    outdir = _IR_UN_DIR / 'tmp'
+def test_ir_sc_func():
+    """Test IR-SC toy example."""
+    outdir = _IR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     outdir_gen = scaffolding(
-        _IR_UN_CONTIG_ATTRS,
-        _IR_UN_CONTIG_LINKS,
-        _IR_UN_CONTIG_STARTER,
+        _IR_SC_CONTIG_ATTRS,
+        _IR_SC_CONTIG_LINKS,
+        _IR_SC_CONTIG_STARTER,
         solver=SOLVER_CBC,
         outdir=outdir,
         instance_name=INSTANCE_NAME_DEF,
         debug=True,
     )
     # TOTEST verify all the debug file
-    verify_scaffolding_ir_un(outdir_gen)
+    verify_scaffolding_ir_sc(outdir_gen)
     rm(outdir)
 
 
-def test_ir_un_cli():
-    """Test IR-UN toy example for cli."""
-    outdir = _IR_UN_DIR / 'tmp'
+def test_ir_sc_cli():
+    """Test IR-SC toy example for cli."""
+    outdir = _IR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     try:
         proc = subprocess.run(
@@ -114,9 +114,9 @@ def test_ir_un_cli():
                 'python3',
                 '-m',
                 'khloraascaf',
-                _IR_UN_CONTIG_ATTRS,
-                _IR_UN_CONTIG_LINKS,
-                _IR_UN_CONTIG_STARTER,
+                _IR_SC_CONTIG_ATTRS,
+                _IR_SC_CONTIG_LINKS,
+                _IR_SC_CONTIG_STARTER,
                 '--solver',
                 SOLVER_CBC,
                 '--debug',
@@ -130,12 +130,12 @@ def test_ir_un_cli():
     except subprocess.CalledProcessError as err:
         raise AssertionError() from err
     outdir_gen = Path(proc.stdout.splitlines()[-1])
-    verify_scaffolding_ir_un(outdir_gen)
+    verify_scaffolding_ir_sc(outdir_gen)
     rm(outdir)
 
 
-def verify_scaffolding_ir_un(outdir_gen: Path):
-    """Verify scaffolding IR-UN.
+def verify_scaffolding_ir_sc(outdir_gen: Path):
+    """Verify scaffolding IR-SC.
 
     Parameters
     ----------
@@ -147,11 +147,11 @@ def verify_scaffolding_ir_un(outdir_gen: Path):
     #
     assert {p.name for p in outdir_gen.glob('*')} == {
         'all_scaffolding.yaml',
-        'contigs_of_regions_khloraascaf_ir_un.tsv',
+        'contigs_of_regions_khloraascaf_ir_sc.tsv',
         'io_config.yaml',
         'map_of_regions_khloraascaf_dr.tsv',
         'map_of_regions_khloraascaf_ir_dr.tsv',
-        'map_of_regions_khloraascaf_ir_un.tsv',
+        'map_of_regions_khloraascaf_ir_sc.tsv',
         'map_of_regions_khloraascaf_ir.tsv',
         'repfrag_khloraascaf_dr.tsv',
         'repfrag_khloraascaf_ir_dr.tsv',
@@ -159,21 +159,21 @@ def verify_scaffolding_ir_un(outdir_gen: Path):
         'solutions.yaml',
         'solver_cbc_khloraascaf_dr.log',
         'solver_cbc_khloraascaf_ir_dr.log',
-        'solver_cbc_khloraascaf_ir_un.log',
+        'solver_cbc_khloraascaf_ir_sc.log',
         'solver_cbc_khloraascaf_ir.log',
         'vertices_of_regions_khloraascaf_dr.tsv',
         'vertices_of_regions_khloraascaf_ir_dr.tsv',
-        'vertices_of_regions_khloraascaf_ir_un.tsv',
+        'vertices_of_regions_khloraascaf_ir_sc.tsv',
         'vertices_of_regions_khloraascaf_ir.tsv',
     }
     #
     # Test maps of regions
     #
     res_map_of_regions = outdir_gen / fmt_map_of_regions_filename(
-        INSTANCE_NAME_DEF, (IR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (IR_REGION_ID, SC_REGION_ID),
     )
     l_sol_map = []
-    with open(_IR_UN_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
+    with open(_IR_SC_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
         for line in sol_map:
             l_sol_map.append(line.split())
     l_res_map = []
@@ -185,14 +185,14 @@ def verify_scaffolding_ir_un(outdir_gen: Path):
     # Test contigs of region
     #
     res_contigs_of_regions = outdir_gen / fmt_contigs_of_regions_filename(
-        INSTANCE_NAME_DEF, (IR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (IR_REGION_ID, SC_REGION_ID),
     )
     l_sol_ctg_f = []
-    with open(_IR_UN_SOL_REGCTG_F, 'r', encoding='utf-8') as sol_ctg:
+    with open(_IR_SC_SOL_REGCTG_F, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg_f.append(line.split())
     l_sol_ctg_r = []
-    with open(_IR_UN_SOL_REGCTG_R, 'r', encoding='utf-8') as sol_ctg:
+    with open(_IR_SC_SOL_REGCTG_R, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg_r.append(line.split())
     l_res_ctg = []
@@ -203,27 +203,27 @@ def verify_scaffolding_ir_un(outdir_gen: Path):
 
 
 # ---------------------------------------------------------------------------- #
-#                                    DR - UN                                   #
+#                                    DR - SC                                   #
 # ---------------------------------------------------------------------------- #
-def test_dr_un_func():
-    """Test DR-UN toy example."""
-    outdir = _DR_UN_DIR / 'tmp'
+def test_dr_sc_func():
+    """Test DR-SC toy example."""
+    outdir = _DR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     outdir_gen = scaffolding(
-        _DR_UN_CONTIG_ATTRS,
-        _DR_UN_CONTIG_LINKS,
-        _DR_UN_CONTIG_STARTER,
+        _DR_SC_CONTIG_ATTRS,
+        _DR_SC_CONTIG_LINKS,
+        _DR_SC_CONTIG_STARTER,
         solver=SOLVER_CBC,
         debug=True,
         outdir=outdir,
     )
-    verify_scaffolding_dr_un(outdir_gen)
+    verify_scaffolding_dr_sc(outdir_gen)
     rm(outdir)
 
 
-def test_dr_un_cli():
-    """Test DR-UN toy example for cli."""
-    outdir = _DR_UN_DIR / 'tmp'
+def test_dr_sc_cli():
+    """Test DR-SC toy example for cli."""
+    outdir = _DR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     try:
         proc = subprocess.run(
@@ -231,9 +231,9 @@ def test_dr_un_cli():
                 'python3',
                 '-m',
                 'khloraascaf',
-                _DR_UN_CONTIG_ATTRS,
-                _DR_UN_CONTIG_LINKS,
-                _DR_UN_CONTIG_STARTER,
+                _DR_SC_CONTIG_ATTRS,
+                _DR_SC_CONTIG_LINKS,
+                _DR_SC_CONTIG_STARTER,
                 '--solver',
                 SOLVER_CBC,
                 '--debug',
@@ -247,12 +247,12 @@ def test_dr_un_cli():
     except subprocess.CalledProcessError as err:
         raise AssertionError() from err
     outdir_gen = Path(proc.stdout.splitlines()[-1])
-    verify_scaffolding_dr_un(outdir_gen)
+    verify_scaffolding_dr_sc(outdir_gen)
     rm(outdir)
 
 
-def verify_scaffolding_dr_un(outdir_gen: Path):
-    """Verify scaffolding DR-UN.
+def verify_scaffolding_dr_sc(outdir_gen: Path):
+    """Verify scaffolding DR-SC.
 
     Parameters
     ----------
@@ -264,10 +264,10 @@ def verify_scaffolding_dr_un(outdir_gen: Path):
     #
     assert {p.name for p in outdir_gen.glob('*')} == {
         'all_scaffolding.yaml',
-        'contigs_of_regions_khloraascaf_dr_un.tsv',
+        'contigs_of_regions_khloraascaf_dr_sc.tsv',
         'io_config.yaml',
         'map_of_regions_khloraascaf_dr_ir.tsv',
-        'map_of_regions_khloraascaf_dr_un.tsv',
+        'map_of_regions_khloraascaf_dr_sc.tsv',
         'map_of_regions_khloraascaf_dr.tsv',
         'map_of_regions_khloraascaf_ir.tsv',
         'repfrag_khloraascaf_dr_ir.tsv',
@@ -277,20 +277,20 @@ def verify_scaffolding_dr_un(outdir_gen: Path):
         'solver_cbc_khloraascaf_dr_ir.log',
         'solver_cbc_khloraascaf_dr.log',
         'solver_cbc_khloraascaf_ir.log',
-        'solver_cbc_khloraascaf_dr_un.log',
+        'solver_cbc_khloraascaf_dr_sc.log',
         'vertices_of_regions_khloraascaf_dr_ir.tsv',
         'vertices_of_regions_khloraascaf_dr.tsv',
         'vertices_of_regions_khloraascaf_ir.tsv',
-        'vertices_of_regions_khloraascaf_dr_un.tsv',
+        'vertices_of_regions_khloraascaf_dr_sc.tsv',
     }
     #
     # Test map of regions
     #
     res_map_of_regions = outdir_gen / fmt_map_of_regions_filename(
-        INSTANCE_NAME_DEF, (DR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (DR_REGION_ID, SC_REGION_ID),
     )
     l_sol_map = []
-    with open(_DR_UN_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
+    with open(_DR_SC_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
         for line in sol_map:
             l_sol_map.append(line.split())
     l_res_map = []
@@ -302,10 +302,10 @@ def verify_scaffolding_dr_un(outdir_gen: Path):
     # Test contigs of regions
     #
     res_contigs_of_regions = outdir_gen / fmt_contigs_of_regions_filename(
-        INSTANCE_NAME_DEF, (DR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (DR_REGION_ID, SC_REGION_ID),
     )
     l_sol_ctg = []
-    with open(_DR_UN_SOL_REGCTG, 'r', encoding='utf-8') as sol_ctg:
+    with open(_DR_SC_SOL_REGCTG, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg.append(line.split())
     l_res_ctg = []
@@ -316,27 +316,27 @@ def verify_scaffolding_dr_un(outdir_gen: Path):
 
 
 # ---------------------------------------------------------------------------- #
-#                                      UN                                      #
+#                                      SC                                      #
 # ---------------------------------------------------------------------------- #
-def test_un_func():
-    """Test UN toy example."""
-    outdir = _UN_DIR / 'tmp'
+def test_sc_func():
+    """Test SC toy example."""
+    outdir = _SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     outdir_gen = scaffolding(
-        _UN_CONTIG_ATTRS,
-        _UN_CONTIG_LINKS,
-        _UN_CONTIG_STARTER,
+        _SC_CONTIG_ATTRS,
+        _SC_CONTIG_LINKS,
+        _SC_CONTIG_STARTER,
         solver=SOLVER_CBC,
         debug=True,
         outdir=outdir,
     )
-    verify_scaffolding_un(outdir_gen)
+    verify_scaffolding_sc(outdir_gen)
     rm(outdir)
 
 
-def test_un_cli():
-    """Test UN toy example for cli."""
-    outdir = _UN_DIR / 'tmp'
+def test_sc_cli():
+    """Test SC toy example for cli."""
+    outdir = _SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     try:
         proc = subprocess.run(
@@ -344,9 +344,9 @@ def test_un_cli():
                 'python3',
                 '-m',
                 'khloraascaf',
-                _UN_CONTIG_ATTRS,
-                _UN_CONTIG_LINKS,
-                _UN_CONTIG_STARTER,
+                _SC_CONTIG_ATTRS,
+                _SC_CONTIG_LINKS,
+                _SC_CONTIG_STARTER,
                 '--solver',
                 SOLVER_CBC,
                 '--debug',
@@ -360,12 +360,12 @@ def test_un_cli():
     except subprocess.CalledProcessError as err:
         raise AssertionError() from err
     outdir_gen = Path(proc.stdout.splitlines()[-1])
-    verify_scaffolding_un(outdir_gen)
+    verify_scaffolding_sc(outdir_gen)
     rm(outdir)
 
 
-def verify_scaffolding_un(outdir_gen: Path):
-    """Verify scaffolding UN.
+def verify_scaffolding_sc(outdir_gen: Path):
+    """Verify scaffolding SC.
 
     Parameters
     ----------
@@ -377,29 +377,29 @@ def verify_scaffolding_un(outdir_gen: Path):
     #
     assert {p.name for p in outdir_gen.glob('*')} == {
         'all_scaffolding.yaml',
-        'contigs_of_regions_khloraascaf_un.tsv',
+        'contigs_of_regions_khloraascaf_sc.tsv',
         'io_config.yaml',
         'map_of_regions_khloraascaf_dr.tsv',
         'map_of_regions_khloraascaf_ir.tsv',
-        'map_of_regions_khloraascaf_un.tsv',
+        'map_of_regions_khloraascaf_sc.tsv',
         'repfrag_khloraascaf_dr.tsv',
         'repfrag_khloraascaf_ir.tsv',
         'solutions.yaml',
         'solver_cbc_khloraascaf_dr.log',
         'solver_cbc_khloraascaf_ir.log',
-        'solver_cbc_khloraascaf_un.log',
+        'solver_cbc_khloraascaf_sc.log',
         'vertices_of_regions_khloraascaf_dr.tsv',
         'vertices_of_regions_khloraascaf_ir.tsv',
-        'vertices_of_regions_khloraascaf_un.tsv',
+        'vertices_of_regions_khloraascaf_sc.tsv',
     }
     #
     # Test map of regions
     #
     res_map_of_regions = outdir_gen / fmt_map_of_regions_filename(
-        INSTANCE_NAME_DEF, (UN_REGION_ID,),
+        INSTANCE_NAME_DEF, (SC_REGION_ID,),
     )
     l_sol_map = []
-    with open(_UN_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
+    with open(_SC_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
         for line in sol_map:
             l_sol_map.append(line.split())
     l_res_map = []
@@ -411,10 +411,10 @@ def verify_scaffolding_un(outdir_gen: Path):
     # Test contigs of regions
     #
     res_contigs_of_regions = outdir_gen / fmt_contigs_of_regions_filename(
-        INSTANCE_NAME_DEF, (UN_REGION_ID,),
+        INSTANCE_NAME_DEF, (SC_REGION_ID,),
     )
     l_sol_ctg = []
-    with open(_UN_SOL_REGCTG, 'r', encoding='utf-8') as sol_ctg:
+    with open(_SC_SOL_REGCTG, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg.append(line.split())
     l_res_ctg = []
@@ -425,29 +425,29 @@ def verify_scaffolding_un(outdir_gen: Path):
 
 
 # ---------------------------------------------------------------------------- #
-#                                 IR - DR - UN                                 #
+#                                 IR - DR - SC                                 #
 # ---------------------------------------------------------------------------- #
-def test_ir_dr_un_func():
-    """Test IR-DR-UN toy example."""
-    outdir = _IR_DR_UN_DIR / 'tmp'
+def test_ir_dr_sc_func():
+    """Test IR-DR-SC toy example."""
+    outdir = _IR_DR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     outdir_gen = scaffolding(
-        _IR_DR_UN_CONTIG_ATTRS,
-        _IR_DR_UN_CONTIG_LINKS,
-        _IR_DR_UN_CONTIG_STARTER,
+        _IR_DR_SC_CONTIG_ATTRS,
+        _IR_DR_SC_CONTIG_LINKS,
+        _IR_DR_SC_CONTIG_STARTER,
         solver=SOLVER_CBC,
         outdir=outdir,
         instance_name=INSTANCE_NAME_DEF,
         debug=True,
     )
     # TOTEST verify all the debug file
-    verify_scaffolding_ir_dr_un(outdir_gen)
+    verify_scaffolding_ir_dr_sc(outdir_gen)
     rm(outdir)
 
 
-def test_ir_dr_un_cli():
-    """Test IR-DR-UN alone toy example for cli."""
-    outdir = _IR_DR_UN_DIR / 'tmp'
+def test_ir_dr_sc_cli():
+    """Test IR-DR-SC alone toy example for cli."""
+    outdir = _IR_DR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     try:
         proc = subprocess.run(
@@ -455,9 +455,9 @@ def test_ir_dr_un_cli():
                 'python3',
                 '-m',
                 'khloraascaf',
-                _IR_DR_UN_CONTIG_ATTRS,
-                _IR_DR_UN_CONTIG_LINKS,
-                _IR_DR_UN_CONTIG_STARTER,
+                _IR_DR_SC_CONTIG_ATTRS,
+                _IR_DR_SC_CONTIG_LINKS,
+                _IR_DR_SC_CONTIG_STARTER,
                 '--solver',
                 SOLVER_CBC,
                 '--debug',
@@ -471,12 +471,12 @@ def test_ir_dr_un_cli():
     except subprocess.CalledProcessError as err:
         raise AssertionError() from err
     outdir_gen = Path(proc.stdout.splitlines()[-1])
-    verify_scaffolding_ir_dr_un(outdir_gen)
+    verify_scaffolding_ir_dr_sc(outdir_gen)
     rm(outdir)
 
 
-def verify_scaffolding_ir_dr_un(outdir_gen: Path):
-    """Verify scaffolding IR-DR-UN.
+def verify_scaffolding_ir_dr_sc(outdir_gen: Path):
+    """Verify scaffolding IR-DR-SC.
 
     Parameters
     ----------
@@ -488,10 +488,10 @@ def verify_scaffolding_ir_dr_un(outdir_gen: Path):
     #
     assert {p.name for p in outdir_gen.glob('*')} == {
         'all_scaffolding.yaml',
-        'contigs_of_regions_khloraascaf_ir_dr_un.tsv',
+        'contigs_of_regions_khloraascaf_ir_dr_sc.tsv',
         'io_config.yaml',
         'map_of_regions_khloraascaf_dr.tsv',
-        'map_of_regions_khloraascaf_ir_dr_un.tsv',
+        'map_of_regions_khloraascaf_ir_dr_sc.tsv',
         'map_of_regions_khloraascaf_ir_dr.tsv',
         'map_of_regions_khloraascaf_ir.tsv',
         'repfrag_khloraascaf_dr.tsv',
@@ -499,11 +499,11 @@ def verify_scaffolding_ir_dr_un(outdir_gen: Path):
         'repfrag_khloraascaf_ir.tsv',
         'solutions.yaml',
         'solver_cbc_khloraascaf_dr.log',
-        'solver_cbc_khloraascaf_ir_dr_un.log',
+        'solver_cbc_khloraascaf_ir_dr_sc.log',
         'solver_cbc_khloraascaf_ir_dr.log',
         'solver_cbc_khloraascaf_ir.log',
         'vertices_of_regions_khloraascaf_dr.tsv',
-        'vertices_of_regions_khloraascaf_ir_dr_un.tsv',
+        'vertices_of_regions_khloraascaf_ir_dr_sc.tsv',
         'vertices_of_regions_khloraascaf_ir_dr.tsv',
         'vertices_of_regions_khloraascaf_ir.tsv',
     }
@@ -511,10 +511,10 @@ def verify_scaffolding_ir_dr_un(outdir_gen: Path):
     # Test maps of regions
     #
     res_map_of_regions = outdir_gen / fmt_map_of_regions_filename(
-        INSTANCE_NAME_DEF, (IR_REGION_ID, DR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (IR_REGION_ID, DR_REGION_ID, SC_REGION_ID),
     )
     l_sol_map = []
-    with open(_IR_DR_UN_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
+    with open(_IR_DR_SC_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
         for line in sol_map:
             l_sol_map.append(line.split())
     l_res_map = []
@@ -526,14 +526,14 @@ def verify_scaffolding_ir_dr_un(outdir_gen: Path):
     # Test contigs of region
     #
     res_contigs_of_regions = outdir_gen / fmt_contigs_of_regions_filename(
-        INSTANCE_NAME_DEF, (IR_REGION_ID, DR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (IR_REGION_ID, DR_REGION_ID, SC_REGION_ID),
     )
     l_sol_ctg_f = []
-    with open(_IR_DR_UN_SOL_REGCTG_F, 'r', encoding='utf-8') as sol_ctg:
+    with open(_IR_DR_SC_SOL_REGCTG_F, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg_f.append(line.split())
     l_sol_ctg_r = []
-    with open(_IR_DR_UN_SOL_REGCTG_R, 'r', encoding='utf-8') as sol_ctg:
+    with open(_IR_DR_SC_SOL_REGCTG_R, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg_r.append(line.split())
     l_res_ctg = []
@@ -544,29 +544,29 @@ def verify_scaffolding_ir_dr_un(outdir_gen: Path):
 
 
 # ---------------------------------------------------------------------------- #
-#                                 DR - IR - UN                                 #
+#                                 DR - IR - SC                                 #
 # ---------------------------------------------------------------------------- #
-def test_dr_ir_un_func():
-    """Test DR-IR-UN toy example."""
-    outdir = _DR_IR_UN_DIR / 'tmp'
+def test_dr_ir_sc_func():
+    """Test DR-IR-SC toy example."""
+    outdir = _DR_IR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     outdir_gen = scaffolding(
-        _DR_IR_UN_CONTIG_ATTRS,
-        _DR_IR_UN_CONTIG_LINKS,
-        _DR_IR_UN_CONTIG_STARTER,
+        _DR_IR_SC_CONTIG_ATTRS,
+        _DR_IR_SC_CONTIG_LINKS,
+        _DR_IR_SC_CONTIG_STARTER,
         solver=SOLVER_CBC,
         outdir=outdir,
         instance_name=INSTANCE_NAME_DEF,
         debug=True,
     )
     # TOTEST verify all the debug file
-    verify_scaffolding_dr_ir_un(outdir_gen)
+    verify_scaffolding_dr_ir_sc(outdir_gen)
     rm(outdir)
 
 
-def test_dr_ir_un_cli():
-    """Test DR-IR-UN alone toy example for cli."""
-    outdir = _DR_IR_UN_DIR / 'tmp'
+def test_dr_ir_sc_cli():
+    """Test DR-IR-SC alone toy example for cli."""
+    outdir = _DR_IR_SC_DIR / 'tmp'
     outdir.mkdir(exist_ok=True)
     try:
         proc = subprocess.run(
@@ -574,9 +574,9 @@ def test_dr_ir_un_cli():
                 'python3',
                 '-m',
                 'khloraascaf',
-                _DR_IR_UN_CONTIG_ATTRS,
-                _DR_IR_UN_CONTIG_LINKS,
-                _DR_IR_UN_CONTIG_STARTER,
+                _DR_IR_SC_CONTIG_ATTRS,
+                _DR_IR_SC_CONTIG_LINKS,
+                _DR_IR_SC_CONTIG_STARTER,
                 '--solver',
                 SOLVER_CBC,
                 '--debug',
@@ -590,12 +590,12 @@ def test_dr_ir_un_cli():
     except subprocess.CalledProcessError as err:
         raise AssertionError() from err
     outdir_gen = Path(proc.stdout.splitlines()[-1])
-    verify_scaffolding_dr_ir_un(outdir_gen)
+    verify_scaffolding_dr_ir_sc(outdir_gen)
     rm(outdir)
 
 
-def verify_scaffolding_dr_ir_un(outdir_gen: Path):
-    """Verify scaffolding DR-IR-UN.
+def verify_scaffolding_dr_ir_sc(outdir_gen: Path):
+    """Verify scaffolding DR-IR-SC.
 
     Parameters
     ----------
@@ -607,9 +607,9 @@ def verify_scaffolding_dr_ir_un(outdir_gen: Path):
     #
     assert {p.name for p in outdir_gen.glob('*')} == {
         'all_scaffolding.yaml',
-        'contigs_of_regions_khloraascaf_dr_ir_un.tsv',
+        'contigs_of_regions_khloraascaf_dr_ir_sc.tsv',
         'io_config.yaml',
-        'map_of_regions_khloraascaf_dr_ir_un.tsv',
+        'map_of_regions_khloraascaf_dr_ir_sc.tsv',
         'map_of_regions_khloraascaf_dr_ir.tsv',
         'map_of_regions_khloraascaf_dr.tsv',
         'map_of_regions_khloraascaf_ir.tsv',
@@ -617,11 +617,11 @@ def verify_scaffolding_dr_ir_un(outdir_gen: Path):
         'repfrag_khloraascaf_dr.tsv',
         'repfrag_khloraascaf_ir.tsv',
         'solutions.yaml',
-        'solver_cbc_khloraascaf_dr_ir_un.log',
+        'solver_cbc_khloraascaf_dr_ir_sc.log',
         'solver_cbc_khloraascaf_dr_ir.log',
         'solver_cbc_khloraascaf_dr.log',
         'solver_cbc_khloraascaf_ir.log',
-        'vertices_of_regions_khloraascaf_dr_ir_un.tsv',
+        'vertices_of_regions_khloraascaf_dr_ir_sc.tsv',
         'vertices_of_regions_khloraascaf_dr_ir.tsv',
         'vertices_of_regions_khloraascaf_dr.tsv',
         'vertices_of_regions_khloraascaf_ir.tsv',
@@ -630,10 +630,10 @@ def verify_scaffolding_dr_ir_un(outdir_gen: Path):
     # Test maps of regions
     #
     res_map_of_regions = outdir_gen / fmt_map_of_regions_filename(
-        INSTANCE_NAME_DEF, (DR_REGION_ID, IR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (DR_REGION_ID, IR_REGION_ID, SC_REGION_ID),
     )
     l_sol_map = []
-    with open(_DR_IR_UN_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
+    with open(_DR_IR_SC_SOL_REGMAP, 'r', encoding='utf-8') as sol_map:
         for line in sol_map:
             l_sol_map.append(line.split())
     l_res_map = []
@@ -645,14 +645,14 @@ def verify_scaffolding_dr_ir_un(outdir_gen: Path):
     # Test contigs of region
     #
     res_contigs_of_regions = outdir_gen / fmt_contigs_of_regions_filename(
-        INSTANCE_NAME_DEF, (DR_REGION_ID, IR_REGION_ID, UN_REGION_ID),
+        INSTANCE_NAME_DEF, (DR_REGION_ID, IR_REGION_ID, SC_REGION_ID),
     )
     l_sol_ctg_f = []
-    with open(_DR_IR_UN_SOL_REGCTG_F, 'r', encoding='utf-8') as sol_ctg:
+    with open(_DR_IR_SC_SOL_REGCTG_F, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg_f.append(line.split())
     l_sol_ctg_r = []
-    with open(_DR_IR_UN_SOL_REGCTG_R, 'r', encoding='utf-8') as sol_ctg:
+    with open(_DR_IR_SC_SOL_REGCTG_R, 'r', encoding='utf-8') as sol_ctg:
         for line in sol_ctg:
             l_sol_ctg_r.append(line.split())
     l_res_ctg = []
